@@ -4,6 +4,7 @@
 #' @template x
 #' @template na-handling
 #' @inheritParams checkVector
+#' @template typed.missing
 #' @template null.ok
 #' @template checker
 #' @family basetypes
@@ -12,8 +13,8 @@
 #' @examples
 #' testComplex(1)
 #' testComplex(1+1i)
-checkComplex = function(x, any.missing = TRUE, all.missing = TRUE, len = NULL, min.len = NULL, max.len = NULL, unique = FALSE, names = NULL, null.ok = FALSE) {
-  .Call(c_check_complex, x, any.missing, all.missing, len, min.len, max.len, unique, names, null.ok)
+checkComplex = function(x, any.missing = TRUE, all.missing = TRUE, len = NULL, min.len = NULL, max.len = NULL, unique = FALSE, names = NULL, typed.missing = FALSE, null.ok = FALSE) {
+  .Call(c_check_complex, x, any.missing, all.missing, len, min.len, max.len, unique, names, typed.missing, null.ok)
 }
 
 #' @export
@@ -24,7 +25,7 @@ check_complex = checkComplex
 #' @include makeAssertion.R
 #' @template assert
 #' @rdname checkComplex
-assertComplex = makeAssertionFunction(checkComplex, c.fun = "c_check_complex")
+assertComplex = makeAssertionFunction(checkComplex, c.fun = "c_check_complex", use.namespace = FALSE)
 
 #' @export
 #' @rdname checkComplex
@@ -43,4 +44,4 @@ test_complex = testComplex
 #' @include makeExpectation.R
 #' @template expect
 #' @rdname checkComplex
-expect_complex = makeExpectationFunction(checkComplex, c.fun = "c_check_complex")
+expect_complex = makeExpectationFunction(checkComplex, c.fun = "c_check_complex", use.namespace = FALSE)
