@@ -1,5 +1,6 @@
 #include <R.h>
 #include <Rinternals.h>
+#include <Rversion.h>
 
 #ifndef LOGICAL_RO
 #define LOGICAL_RO(x) ((const int *) LOGICAL(x))
@@ -16,3 +17,7 @@
 #ifndef COMPLEX_RO
 #define COMPLEX_RO(x) ((const Rcomplex *) COMPLEX(x))
 #endif
+
+#if R_VERSION < R_Version(4, 5, 0)
+# define isDataFrame(x) Rf_isFrame(x)
+#endif
