@@ -10,3 +10,8 @@ test_that("checkScalarNA", {
 
   expect_error(assertScalarNA(integer(0)), "missing value")
 })
+
+test_that("checkScalarNA on data.frame/data.table (#245)", {
+  df = data.frame(x = 1:2)
+  expect_false(testScalarNA(df))
+})
